# Software License Agreement for HALCON 22.11

IMPORTANT - READ CAREFULLY:

This Software License Agreement (Agreement) is a legal Agreement between you (either an individual or a single entity) and MVTec Software GmbH (MVTec) for the MVTec software product identified above, which includes computer software and may include associated media, printed materials and online or electronic documentation.

YOU AGREE TO BE BOUND BY THE TERMS OF THIS AGREEMENT BY INSTALLING, OR OTHERWISE USING THE PRODUCT. IF YOU DO NOT AGREE, DO NOT INSTALL OR USE THE PRODUCT.

YOU MAY RECEIVE A REFUND OF THE AMOUNT YOU ORIGINALLY PAID IF YOU (1) DO NOT USE THE SOFTWARE AND (2) RETURN IT, WITH PROOF OF PAYMENT, TO THE LOCATION FROM WHICH IT WAS OBTAINED WITHIN THIRTY (30) DAYS OF THE PURCHASE DATE.

MVTec grants you the rights described in this Agreement provided that you comply with all terms and conditions of this Agreement.

## DEFINITIONS

“Derivative” means a computer software (application) created by you that includes or is based in whole or in part on the Software, including, but not limited to, incorporating the Software into the Derivative by linking or otherwise using the Software in any form whatsoever in your Derivative.

“Documentation” means the User’s Guides, Solution Guides, Reference Manuals, Programmer’s Manuals, Technical Notes, if any, accompanying delivery of the Software. Documentation may be delivered in printed and/or electronic and/or online forms.

“Edition” means the Progress Edition or the Steady Edition of the Software.

“Evaluation License” means a license, supplied to you in the form of a License File that allows you to install and evaluate the Software on any computer for a certain period of time.

“License File” means a computer file that contains license keys that permit you to use the Software in a particular Software Configuration.

“Nodelocked License” means a license, supplied to you in the form of a License File that allows you to install and use the Software only on the computer specified in the License File.

“Network License” means a license, supplied to you in the form of a License File, that allows you to install the Software on any number of computers which are intended to run the Software but limits the number of simultaneous uses of the Software to the number of licenses specified in the License File.

“License Type” means a Nodelocked License or Network License.

“Software” means all of the contents of the files, disk(s), CD-ROM(s), DVD(s) or other media with which this Agreement is provided, including but not limited to, MVTec or third party computer software, digital images, example programs and Documentation; this also includes upgrades, modified versions, updates, additions and copies of the Software, if any, licensed, delivered and provided to you by MVTec. The term "Software" does not include any Derivatives or other programs which may include the Software delivered and provided to you by MVTec.

“Protected Data” includes all files of Software which format or content has not been disclosed by MVTec and if it has been disclosed, then the sole discloser must be MVTec.

“Software Configuration” means the Evaluation Version, the Development Version, or the Runtime Version of the Software.

“Subscription Term” means the time period for which certain rights of the Progress Edition are granted. The Subscription Term is one (1) year.

## LICENSE GRANT

MVTec grants to you a nonexclusive license to install and use the Software as provided herein. The licensed Software and Documentation shall at all time remain the property of MVTec and/or its licensors, and you, as licensee, shall have no right, title, or interest in the Software, except as expressly set forth in this Agreement.

The transfer of the Software, including, but not limited to, sublicensing and distribution to a third party is not permitted.

### EDITIONS, SOFTWARE CONFIGURATIONS AND LICENSE OPTIONS

Different rights, obligations and restrictions apply to each Edition, Software Configuration, and License Type. Your right to install and use the Software is determined by the Edition and Software Configuration selected and the associated License Type, as set forth below:

#### STEADY EDITION

The Steady Edition provides unlimited access to the Software, containing both a Development and a Runtime Version, as described within the provisions below.

#### PROGRESS EDITION

The Progress Edition provides access to the Software based on a subscription of a Software Configuration, as described within the provisions below. Once you subscribe to the Progress Edition, your subscription will be automatically renewed by the end of the Subscription Term as long as you don’t terminate your subscription three (3) months prior to the end of the Subscription Term. “Renew” shall mean to apply the same length of the Subscription Term once again.

#### SOFTWARE CONFIGURATION OPTIONS

##### Evaluation Version

The Evaluation Version is a version of the Software that allows you to evaluate the full functionality of the Software for a certain period of time, typically one (1) month. It is available for both Editions and requires a corresponding Evaluation License File.

The Software may be installed on any number of computers. Your right to use the Software and to create Derivatives is restricted to the purpose of evaluating the Software. Except as aforesaid, you may not use the Software for any other purposes, including, but not limited to, commercial purposes. In particular, you may not use the Evaluation Version to develop commercial applications.

The Evaluation Version may be used only in the time period that is specified in the Evaluation License File. After expiration of this time period, the Software will no longer work.

##### DEVELOPMENT VERSION

The Development Version is a version of the Software that allows you to use the functionality of the Software as described in the Documentation for a certain period of time. For the Steady Edition, the period of time is unlimited; for the Progress Edition, the period of time is the Subscription Term. The Development Version requires a License File containing license keys that permit you to use the Development Version. The scope of your right to install and use the Development Version depends on the License Type. In case of a Nodelocked License the Software may only be installed on the computer specified in the License File, see Section 2.2.1, or on a build system. You may use the Software to create Derivatives, including commercial applications. In particular, you may use the Development Version to compile and link applications. Such applications may also be compiled or linked on build systems.

##### RUNTIME VERSION

Your right to purchase the Runtime Version depends on the Edition. The Steady Edition allows you to purchase the Runtime Version for an unlimited period of time, provided that you own a corresponding Development Version. The Progress Edition allows you to purchase the Runtime Version only during the Subscription Term.

The Runtime Version is a version of the Software that allows you to use the runtime functionality of the Software. In particular, certain development tools of the Software cannot be used, as described in the Documentation.

The Runtime Version requires a License File containing license keys that permit you to use the Runtime Version.The scope of your right to install and use the Runtime Version depends on the License Type. In case of a Nodelocked License the Software may only be installed on the computer specified in the License File, see Section 2.2.1.

You may distribute and sublicense Derivatives. or must possess a valid license for the Development Version before you are authorized to distribute and/or sublicense your Derivatives. The Runtime Version may not be used for the creation of Derivatives, including, but not limited to, compiling and linking of applications.

If you are authorized and choose to distribute such Derivatives, you agree (1) not to use MVTec's name, logo or trademarks to market the Derivatives; (2) to display your own valid copyright notice which shall be sufficient to protect MVTec's copyright in the Software; (3) not to remove or obscure any copyright, trademark or patent notice that appear on the Software as delivered to you; (4) to accompany the Derivative with a license whose terms and conditions are at least as restrictive as the terms in this Agreement; (5) to explicitly exclude MVTec and its suppliers from all liability for damages or any obligation to provide remedial actions that may result from the use and distribution of Derivatives; (6) to indemnify, hold harmless and defend MVTec from and against any claims or lawsuits, including attorney's fees, that arise or result from your culpable use or distribution of the Derivatives; (7) otherwise comply with the terms of this Agreement; and (8) agree that MVTec reserves all rights not expressly granted.

MVTec shall have no support or warranty obligations, and disclaims all liability, for Derivatives developed and/or distributed by you. In particular, you will be solely responsible to your end users (or anyone else who uses your Derivatives) for support, service, upgrades, or technical or other assistance, and such persons will have no right to contact MVTec for any services or assistance. Your rights with regard to Software remain unaffected.

### LICENSE TYPES

#### NODELOCKED LICENSES

A Nodelocked License allows you to install and use the Software only on the computer specified in the License File, with the exception specified in Section 2.1.3.2. The computer is specified by a Host ID that is derived from a certain hardware component, which may be bound to an irremovable computer component (Irremovable Host ID), for example, a network card, or may be bound to a removable hardware component (Removable Host ID), for example, a dongle.

If you use an Irremovable Host ID for licensing the Software, you may only install and use the Software on the computer that includes the Irremovable Host ID. If you use a Removable Host ID you may install the Software on any number of computers, but you may only use the Software on the computer to which the Removable Host ID is connected.

#### NETWORK LICENSES

A Network License allows you to install the Software on any number of computers which are intended to run the Software. However, a Network License limits the number of simultaneous uses of the Software to the number of licenses specified in the License File. The Network License requires that a special program, the License Server, is licensed and installed on one computer in the network. The License Server computer is specified by a Host ID that is derived from a dongle (Removable Host ID). The License Server may only be executed on the computer to which the Removable Host ID is attached. You are obliged to stop the execution of the License Server before moving the Removable Host ID to a different computer.

### COMPLIANCE WITH LICENSES

You undertake to keep true, accurate, and consistent books and records containing regular entries relating to duplication and installations of the Software and sales, distributions, or other transfers of Derivatives. MVTec, its authorized representative, or its accountants (subject to your prior written approval, which shall not be unreasonably withheld) may, for the purpose of confirming your compliance with the terms hereof, enter your place of business on reasonable written notice, but not less than five (5) business days, during normal business hours once per year during the term of this Agreement and once following the termination or expiration of this Agreement. MVTec, its authorized representative or its accountants shall be entitled to perform an audit of your relevant books, records, and software systems, and receive any explanations that may reasonably be requested. MVTec shall be responsible for its costs incurred in connection with any such audit, provided that you shall reimburse MVTec for the cost of the audit if the examination discloses an underpayment to MVTec of more than ten percent (10%) of the payments due with respect to any applicable period. Any further rights of MVTec remain unaffected. This Section 2.3 shall survive any termination or expiration of this Agreement for a period of three (3) years.

You further agree that upon request from MVTec or MVTec's authorized representative, you will within thirty (30) days fully document and certify that use of any and all Software at the time of the request is in conformity with your valid licenses from MVTec.

### DOCUMENTATION

You may make and use a reasonable number of copies of any Documentation, provided that such copies shall be used only for internal purposes and are not to be republished or distributed (either in hard copy or electronic form) beyond your premises. In particular, you may not forward any Documentation to your customers as a part of Derivatives.

### EXAMPLE PROGRAMS AND IMAGES

MVTec grants you the right to use and modify the example programs and example images included in the Software for the sole purposes of designing, developing, and testing your software product(s). Example programs are stored in the directory "examples" in the directory or directories in which you have installed the Software, while example images are stored in the directory "examples/images".

## DESCRIPTION OF OTHER RIGHTS AND LIMITATIONS

### RENTAL

You may not rent, lease, or lend the Software.

### BACKUP COPY

You may make a reasonable number of copies of the Software to backup devices such as hard disks, optical media, or tape and a reasonable number of physical DVD media backup copies of the Software solely to replace the original copy provided to you if the original copy is damaged or destroyed. All rights not specifically granted to you herein are retained by MVTec.

### LIMITATION ON REVERSE ENGINEERING, DECOMPILATION, DISASSEMBLY AND MODIFICATION

You may not reverse engineer, decompile, disassemble, or otherwise attempt to discover the source code of the Software or the file format or content of its Protected Data, unless you are explicitly permitted by law to do so. If it is essential to do so in order to achieve interoperability of the Software with other software programs, you shall request MVTec to provide the information necessary to achieve such interoperability and MVTec will provide such information upon mutual consent.

MVTec has the right to impose reasonable conditions and to request a reasonable fee before providing such information. Any information supplied by MVTec or obtained by you, as permitted hereunder, may only be used by you for the purpose described herein and may not be disclosed to any third party.

You may not modify, adapt, or otherwise alter the Software or Protected Data except as expressly permitted herein. In particular, you may not attempt to remove the license protection mechanism from the Software.

### TRADEMARKS

This Agreement does not grant you any rights in connection with any trademarks or service marks of MVTec. You may not use the name, trademarks, or service marks of MVTec in any advertising, promotional literature, or any other material, whether in written, electronic, or other form, distributed to any third party, except as expressly permitted by MVTec.

### UPGRADES

Different rights and obligations apply to the Editions and Software Configurations as listed in the following provisions.

#### Steady Edition

If the Software either in its Development Version or Runtime Version is an upgrade to a previous version of the Software, you must possess a valid license to such previous version in order to use the upgrade. You may continue to use the previous version of the Software on your computer after you receive the upgrade, provided that (i) the previous version or copies thereof are not transferred to another party or computer unless all copies of the upgrade are also transferred to such party or computer; and (ii) you acknowledge that any obligation MVTec may have to support the previous version of the Software ends upon availability of the upgrade.

#### Progress Edition

You may use any upgrade of the Development Version published within the Subscription Term provided that you possess a valid license to such previous version in order to use the upgrade. You may continue to use the previous version of the Development Version of the Software on your computer after you receive the upgrade, provided that (i) the previous version or copies thereof are not transferred to another party or computer unless all copies of the upgrade are also transferred to such party or computer; and (ii) you acknowledge that any obligation MVTec may have to support a previous version of the Development Version of the Software ends upon availability of the upgrade to such previous version.

You may use any upgrade of the Runtime Version published within two (2) years after purchase date provided that (i) the purchase date falls within a Subscription Term and (ii) that you possess a valid license to such previous version in order to use the upgrade. You may continue to use the previous version of the Runtime Version of the Software on your computer, provided that (i) said previous version or copies thereof are not transferred to another party or computer unless all copies of the upgrade are also transferred to such party or computer; and (ii) you acknowledge that any obligation MVTec may have to support the previous version of the Runtime Version of the Software ends upon availability of the upgrade.

You may choose to use previous versions of the Runtime Version of the Software published before the purchase date provided that (i) the purchase date falls within a Subscription Term and (ii) that you possess a valid license of the Runtime Version. In this case you acknowledge that any obligation MVTec may have to support a previous version of the Runtime Version of the Software ends upon availability of the upgrade to such previous version.

### LICENSE FOR THIRD PARTY SOFTWARE

MVTec has been granted licenses to distribute certain third party software. As a condition of those licenses, MVTec is required to distribute the software subject to specific terms and conditions, which may be different from or additional to those contained herein for MVTec's Software. All third party software and the respective licence terms will be listed in the Documentation and will also be provided upon request. The documentation also describes which third party software is used by which part of the Software. Your use of a certain part of the Software requires that you accept the license terms of the third party software that is used by this part of the Software (the Used Third Party Software). You understand and agree that acceptance of this Agreement also confirms your acceptance of the applicable provisions for use, including the restrictions on use, of the Used Third Party Software. Any breach of the applicable provisions of any third party's license terms shall also be considered a material breach of this Agreement.

### Expiration of the right to use

As soon as the right to use the Software has ended (e.g., after the expiration of the time period of a Software Configuration), you must destroy all copies of the Software.

### TERMINATION

Without prejudice to any other rights, MVTec may terminate this Agreement if you fail to comply with the terms and conditions of this Agreement. In such event, you must destroy all copies of the Software as well as all Derivatives.

## INTELLECTUAL PROPERTY RIGHTS

The Software is protected by copyright and other intellectual property laws and treaties. All title and intellectual property rights in and to the Software, including, but not limited to, any digital images or example programs, incorporated into the Software, the Documentation, and any copies of the Software are owned by MVTec or its suppliers. The Software is licensed, not sold.

## LIMITED WARRANTY

MVTec warrants to the person or entity that first purchases a license for the Software that the Software will perform in all material aspects in accordance with the Documentation for a period of twelve (12) months following receipt of the Software when used on a recommended hardware configuration. The warranty period shall be according to statutory law in cases of intent or gross negligence on the part of MVTec.

Non-substantial variations of performance of the Software from the Documentation does not establish a warranty right. This warranty does not apply to updates, upgrades, pre-releases, or to Software that has been altered by you, to the extent such alterations caused a defect. To make a warranty claim, you must return the Software to the location where you obtained it along with proof of purchase within the period of time set forth above.

If the Software does not perform substantially in accordance with the Documentation, MVTec may, in its sole discretion repair or replace the Software.

EXCEPT FOR THIS EXPRESS LIMITED WARRANTY, THE PRODUCT IS PROVIDED WITHOUT WARRANTY OF ANY KIND. MVTEC HEREBY EXCLUDES AND DISCLAIMS ALL IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, ANY WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. YOUR STATUTORY WARRANTY RIGHTS SHALL REMAIN UNAFFECTED SUBJECT TO THE EXPRESS TERMS OF THIS AGREEMENT.

## LIMITATION OF LIABILITY

MVTEC'S LIABILITY IS UNLIMITED IN CASE OF INTENT AND GROSS NEGLIGENCE.

MVTEC IS LIABLE FOR SLIGHT NEGLIGENCE ONLY: (1) FOR DAMAGES RESULTING FROM INJURY TO LIFE, BODY OR HEALTH; OR (2) FOR DAMAGES ARISING FROM THE BREACH OF A MATERIAL CONTRACTUAL OBLIGATION (I.E. AN OBLIGATION, THAT IS ABSOLUTELY NECESSARY FOR THE FULFILLMENT OF THIS AGREEMENT OR UPON WHICH YOU HAVE REASONABLY RELIED ON); IN SUCH CASE, HOWEVER, LIABILITY IS LIMITED TO THE REPLACEMENT OF THE FORESEEABLE, TYPICALLY OCCURRING DAMAGE.

THE ABOVE LIMITATIONS OF LIABILITY SHALL NOT APPLY IF MVTEC FRAUDULENTLY CONCEALS A DEFECT OR IF MVTEC HAS ACCEPTED A GUARANTEE FOR THE QUALITY OF THE SOFTWARE. THE SAME APPLIES TO YOUR CLAIMS UNDER THE GERMAN PRODUCT LIABILITY ACT.

FURTHER LIABILITY OF MVTEC IS EXCLUDED.

## HAZARDOUS USES

The Software is not designed and/or intended for use in connection with any application requiring fail-safe performance, such as the operation of nuclear power facilities, air traffic control or navigation systems, weapon control systems, life support systems, or any other system whose failure could lead to death, personal injury, or severe physical or environmental damage (High Risk Use). You agree that you may not use the Software in such High Risk Use scenarios.

## ENTIRE AGREEMENT/SEVERABILITY

This Agreement contains the entire, final, and exclusive understanding between MVTec and you, and may not be modified or amended except by written instrument, executed by authorized representatives of MVTec and you. If any provisions of this Agreement are held to be illegal, invalid, or enforceable for any reason, the remainder of the provisions of this license will remain in full force and effect and you and MVTec will agree on the replacement of the invalid contractual provision by an appropriate provision which comes as close as possible to what you and MVTec would have wanted, had they considered the point.

## APPLICABLE LAW

This Software License Agreement is governed by the laws of Germany. The 1980 United Nations Convention on Contracts for the International Sale of Goods shall not apply. All of the disputes arising from this Software License Agreement and in association with it will be resolved exclusively by the courts of Munich.